# Usage Guide

## Project Configuration

TODO:: discuss how to edit the configuration files in the `config/` directory to match your research parameters

TODO:: discuss how to add your input data to the `data/rawdata/` directory and document it properly in the `docs/data_sources/` directory

TODO:: discuss how to manage and organize your data sources effectively

## Running Your Analysis

TODO:: discuss using pixi tasks to run the analysis
